@@ -1,17 +1,17 @@
 # pylint:disable=global-statement
-from typing import Optional
+import ctypes
+import datetime
 import logging
 import time
-import datetime
-import ctypes
+from typing import Optional
 
-from ...logic import GlobalInfo
-from ...logic.threads import gui_thread_schedule_async
+from angrmanagement.logic import GlobalInfo
+from angrmanagement.logic.threads import gui_thread_schedule_async
 
 m = ...
 
 
-l = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 def _load_autoreload():
@@ -55,7 +55,7 @@ class Job:
                 m.check()
                 poststate = dict(m.modules_mtimes)
                 if prestate != poststate:
-                    l.warning("Autoreload found changed modules")
+                    log.warning("Autoreload found changed modules")
 
     @property
     def time_elapsed(self) -> str:
@@ -83,7 +83,7 @@ class Job:
             res = ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(tid), ctypes.py_object(KeyboardInterrupt))
             if res != 1:
                 ctypes.pythonapi.PyThreadState_SetAsyncExc(ctypes.c_long(tid), 0)
-                l.error("Failed to interrupt thread")
+                log.error("Failed to interrupt thread")
 
     def _progress_callback(self, percentage, text=None):
         delta = percentage - self.progress_percentage
