@@ -1,10 +1,9 @@
-import traceback
 import logging
+import traceback
 
-from ..utils.namegen import NameGenerator
+from angrmanagement.utils.namegen import NameGenerator
 
-
-l = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 
 class EventSentinel:
@@ -22,7 +21,7 @@ class EventSentinel:
                 self.am_subscribers.remove(listener)
             except ValueError:
                 if self.am_logging_permitted:
-                    l.warning("Double-unsubscribe of %s from %s", listener, self)
+                    log.warning("Double-unsubscribe of %s from %s", listener, self)
                 else:
                     print("Double-unsubscribe of listener")  # No f-string in case str uses logging
                     traceback.print_exc()
@@ -33,7 +32,7 @@ class EventSentinel:
                 listener(**kwargs)
             except Exception:  # pylint: disable=broad-except
                 if self.am_logging_permitted:
-                    l.exception("Error raised from event of %s", self)
+                    log.exception("Error raised from event of %s", self)
                 else:
                     print("Error raised from event")  # No f-string in case str uses logging
                     traceback.print_exc()
