@@ -1,2 +1,7 @@
-from .load_components_dialog import LoadComponentsDialog
 from .components_treeview import ComponentsView
+from .load_components_dialog import LoadComponentsDialog
+
+__all__ = [
+    "ComponentsView",
+    "LoadComponentsDialog",
+]
