@@ -1,6 +1,15 @@
 from .analysis_options import AnalysisOptionsDialog
-from .load_binary import LoadBinary
-from .load_plugins import LoadPlugins
-from .load_docker_prompt import LoadDockerPrompt
-from .preferences import Preferences
 from .breakpoint import BreakpointDialog
+from .load_binary import LoadBinary
+from .load_docker_prompt import LoadDockerPrompt
+from .load_plugins import LoadPlugins
+from .preferences import Preferences
+
+__all__ = [
+    "AnalysisOptionsDialog",
+    "BreakpointDialog",
+    "LoadBinary",
+    "LoadDockerPrompt",
+    "LoadPlugins",
+    "Preferences",
+]
