@@ -1,5 +1,5 @@
-from PySide6.QtWidgets import QDialog, QVBoxLayout, QLabel, QDialogButtonBox, QPlainTextEdit, QApplication
 from PySide6.QtCore import Qt
+from PySide6.QtWidgets import QApplication, QDialog, QDialogButtonBox, QLabel, QPlainTextEdit, QVBoxLayout
 
 
 class QCommentTextBox(QPlainTextEdit):
@@ -52,7 +52,6 @@ class SetComment(QDialog):
     #
 
     def _init_widgets(self):
-
         # name label
         comment_lbl = QLabel(self)
         comment_lbl.setText("Comment text")
