@@ -1,4 +1,11 @@
+from .debug_toolbar import DebugToolbar
 from .file_toolbar import FileToolbar
 from .function_table_toolbar import FunctionTableToolbar
 from .nav_toolbar import NavToolbar
-from .debug_toolbar import DebugToolbar
+
+__all__ = [
+    "DebugToolbar",
+    "FileToolbar",
+    "FunctionTableToolbar",
+    "NavToolbar",
+]
