@@ -1,14 +1,20 @@
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 import qtawesome as qta
-from PySide6.QtCore import QAbstractItemModel, Qt, QModelIndex
+from PySide6.QtCore import QAbstractItemModel, QModelIndex, Qt
 from PySide6.QtGui import QAction
-from PySide6.QtWidgets import QLabel, QComboBox, QMenu
+from PySide6.QtWidgets import QComboBox, QLabel, QMenu
+
+from angrmanagement.config import Conf
+from angrmanagement.logic.debugger import Debugger, DebuggerListManager, DebuggerManager, DebuggerWatcher
 
-from ...logic.debugger import DebuggerWatcher
-from ...config import Conf
 from .toolbar import Toolbar, ToolbarAction, ToolbarSplitter
 
+if TYPE_CHECKING:
+    from angrmanagement.data.instance import Instance
+    from angrmanagement.ui.main_window import MainWindow
+    from angrmanagement.ui.workspace import Workspace
+
 
 class AvailableDebuggersModel(QAbstractItemModel):
     """
@@ -17,8 +23,8 @@ class AvailableDebuggersModel(QAbstractItemModel):
 
     def __init__(self, workspace: "Workspace"):
         super().__init__()
-        self.debugger_mgr: "DebuggerManager" = workspace.main_instance.debugger_mgr
-        self.debugger_list_mgr: "DebuggerListManager" = workspace.main_instance.debugger_list_mgr
+        self.debugger_mgr: DebuggerManager = workspace.main_instance.debugger_mgr
+        self.debugger_list_mgr: DebuggerListManager = workspace.main_instance.debugger_list_mgr
         self.last_str = {}
 
     def rowCount(self, parent):  # pylint:disable=unused-argument
@@ -41,10 +47,10 @@ class AvailableDebuggersModel(QAbstractItemModel):
         self.last_str[row] = "No Debugger" if dbg is None else str(dbg)
         return self.last_str[row]
 
-    def debugger_to_index(self, dbg: Optional["Debugger"]) -> int:
+    def debugger_to_index(self, dbg: Optional[Debugger]) -> int:
         return 0 if dbg is None else (self.debugger_list_mgr.debugger_list.index(dbg) + 1)
 
-    def index_to_debugger(self, index: int) -> Optional["Debugger"]:
+    def index_to_debugger(self, index: int) -> Optional[Debugger]:
         return None if index == 0 else (self.debugger_list_mgr.debugger_list[index - 1])
 
 
@@ -172,7 +178,10 @@ class DebugToolbar(Toolbar):
     def _update_state(self):
         dbg = self._dbg_mgr.debugger.am_obj
         dbg_active = dbg is not None
-        q = lambda a: self._cached_actions[a]
+
+        def q(a):
+            return self._cached_actions[a]
+
         q(self._step_act).setEnabled(dbg_active and dbg.can_step_forward)
         q(self._step_over_act).setEnabled(dbg_active and dbg.can_step_forward)
         q(self._step_backward_act).setEnabled(dbg_active and dbg.can_step_backward)
