@@ -1,48 +1,52 @@
-from collections import defaultdict
 import logging
-from typing import Union, Optional, Tuple, TYPE_CHECKING
+from collections import defaultdict
+from typing import TYPE_CHECKING, Optional, Tuple, Union
 
-import PySide6
-from PySide6.QtWidgets import QHBoxLayout, QVBoxLayout, QApplication, QMessageBox, QMenu
-from PySide6.QtCore import Qt, Signal
-from PySide6.QtGui import QCursor, QAction
 from angr.block import Block
 from angr.knowledge_plugins.cfg import MemoryData
+from PySide6.QtCore import Qt, Signal
+from PySide6.QtGui import QAction, QCursor
+from PySide6.QtWidgets import QApplication, QHBoxLayout, QMenu, QMessageBox, QVBoxLayout
 
-from ...logic import GlobalInfo
-from ...data.instance import ObjectContainer
-from ...utils import locate_function
-from ...data.function_graph import FunctionGraph
-from ...data.highlight_region import SynchronizedHighlightRegion
-from ...logic.disassembly import JumpHistory, InfoDock
-from ..widgets import (
-    QDisassemblyGraph,
-    QDisasmStatusBar,
-    QLinearDisassembly,
-    QFeatureMap,
-    QLinearDisassemblyView,
+from angrmanagement.data.function_graph import FunctionGraph
+from angrmanagement.data.highlight_region import SynchronizedHighlightRegion
+from angrmanagement.data.instance import ObjectContainer
+from angrmanagement.logic import GlobalInfo
+from angrmanagement.logic.disassembly import InfoDock, JumpHistory
+from angrmanagement.ui.dialogs.dependson import DependsOn
+from angrmanagement.ui.dialogs.func_doc import FuncDocDialog
+from angrmanagement.ui.dialogs.hook import HookDialog
+from angrmanagement.ui.dialogs.jumpto import JumpTo
+from angrmanagement.ui.dialogs.new_state import NewState
+from angrmanagement.ui.dialogs.rename import RenameDialog
+from angrmanagement.ui.dialogs.rename_label import RenameLabel
+from angrmanagement.ui.dialogs.set_comment import SetComment
+from angrmanagement.ui.dialogs.xref import XRefDialog
+from angrmanagement.ui.menus.disasm_insn_context_menu import DisasmInsnContextMenu
+from angrmanagement.ui.menus.disasm_label_context_menu import DisasmLabelContextMenu
+from angrmanagement.ui.widgets import (
     DisassemblyLevel,
+    QAvoidAddrAnnotation,
+    QBlockAnnotations,
+    QDisasmStatusBar,
+    QDisassemblyGraph,
+    QFeatureMap,
+    QFindAddrAnnotation,
+    QLinearDisassembly,
+    QLinearDisassemblyView,
 )
-from ..dialogs.dependson import DependsOn
-from ..dialogs.jumpto import JumpTo
-from ..dialogs.rename import RenameDialog
-from ..dialogs.rename_label import RenameLabel
-from ..dialogs.set_comment import SetComment
-from ..dialogs.new_state import NewState
-from ..dialogs.xref import XRefDialog
-from ..dialogs.hook import HookDialog
-from ..dialogs.func_doc import FuncDocDialog
-from ..menus.disasm_insn_context_menu import DisasmInsnContextMenu
-from ..menus.disasm_label_context_menu import DisasmLabelContextMenu
+from angrmanagement.ui.widgets.qblock_code import QVariableObj
+from angrmanagement.ui.widgets.qinst_annotation import QBreakAnnotation, QHookAnnotation
+from angrmanagement.utils import locate_function
+
 from .view import SynchronizedView
-from ..widgets import QFindAddrAnnotation, QAvoidAddrAnnotation, QBlockAnnotations
-from ..widgets.qblock_code import QVariableObj
-from ...ui.widgets.qinst_annotation import QHookAnnotation, QBreakAnnotation
 
 if TYPE_CHECKING:
-    from angrmanagement.logic.disassembly.info_dock import OperandDescriptor
+    import PySide6
     from angr.knowledge_plugins import VariableManager
 
+    from angrmanagement.logic.disassembly.info_dock import OperandDescriptor
+
 
 _l = logging.getLogger(__name__)
 
@@ -111,7 +115,6 @@ class DisassemblyView(SynchronizedView):
         self.redraw_current_graph()
 
     def reload(self):
-
         old_infodock = self.infodock.copy()
 
         self.infodock.initialize()
@@ -301,7 +304,7 @@ class DisassemblyView(SynchronizedView):
         menu.addSeparator()
         menu.addMenu(self.get_synchronize_with_submenu())
 
-    def contextMenuEvent(self, event: PySide6.QtGui.QContextMenuEvent):  # pylint: disable=unused-argument
+    def contextMenuEvent(self, event: "PySide6.QtGui.QContextMenuEvent"):  # pylint: disable=unused-argument
         """
         Display view context menu.
         """
@@ -310,7 +313,6 @@ class DisassemblyView(SynchronizedView):
         mnu.exec_(QCursor.pos())
 
     def instruction_context_menu(self, insn, pos):
-
         self._insn_addr_on_context_menu = insn.addr
 
         # pass in the instruction address
@@ -325,7 +327,6 @@ class DisassemblyView(SynchronizedView):
         self._insn_addr_on_context_menu = None
 
     def label_context_menu(self, addr: int, pos):
-
         self._label_addr_on_context_menu = addr
         self._label_menu.addr = addr
         mnu = self._label_menu.qmenu(cached=False)
@@ -495,7 +496,6 @@ class DisassemblyView(SynchronizedView):
                 self.popup_xref_dialog(addr=ins_addr, dst_addr=operand.constant_memory_value, async_=async_)
 
     def popup_xref_dialog(self, addr=None, variable=None, dst_addr=None, async_=True):
-
         if variable is not None:
             dialog = XRefDialog(
                 addr=addr,
@@ -575,7 +575,6 @@ class DisassemblyView(SynchronizedView):
         self._display_function(function)
 
     def decompile_current_function(self):
-
         if self._current_function.am_obj is not None:
             try:
                 curr_ins = next(iter(self.infodock.selected_insns))
@@ -659,7 +658,6 @@ class DisassemblyView(SynchronizedView):
                 self._flow_graph.reload()
 
     def jump_to(self, addr, src_ins_addr=None, use_animation=False):
-
         # Record the current instruction address first
         if src_ins_addr is not None:
             self.jump_history.record_address(src_ins_addr)
@@ -689,7 +687,6 @@ class DisassemblyView(SynchronizedView):
 
     def rename_label(self, addr, new_name, is_func: bool = False, full_refresh: bool = False):
         if self._flow_graph.disasm is not None:
-
             is_renaming = False
 
             kb = self._flow_graph.disasm.kb
