@@ -1,11 +1,15 @@
-from PySide6.QtGui import QColor
-from PySide6.QtWidgets import QWidget, QHBoxLayout, QFrame, QLabel, QColorDialog
+from typing import TYPE_CHECKING
 
-from ...data.object_container import ObjectContainer
+from PySide6.QtWidgets import QColorDialog, QFrame, QHBoxLayout, QLabel, QWidget
+
+from angrmanagement.data.object_container import ObjectContainer
+
+if TYPE_CHECKING:
+    from PySide6.QtGui import QColor
 
 
 class QColorOption(QWidget):
-    def __init__(self, color: QColor, label: str, parent=None):
+    def __init__(self, color: "QColor", label: str, parent=None):
         super().__init__(parent=parent)
 
         self.color = ObjectContainer(color, "The current color")
