@@ -1,14 +1,13 @@
-from typing import Optional, TYPE_CHECKING
-
-from PySide6.QtCore import Qt
-from PySide6.QtWidgets import QWidget, QVBoxLayout, QLineEdit, QTreeWidget, QTreeWidgetItem, QPushButton, QComboBox
+from typing import TYPE_CHECKING, Optional
 
 from angr.analyses.decompiler.decompilation_options import options as dec_options
-from angr.analyses.decompiler.optimization_passes import get_optimization_passes, get_default_optimization_passes
+from angr.analyses.decompiler.optimization_passes import get_default_optimization_passes, get_optimization_passes
 from angr.analyses.decompiler.peephole_optimizations import EXPR_OPTS, STMT_OPTS
+from PySide6.QtCore import Qt
+from PySide6.QtWidgets import QComboBox, QLineEdit, QPushButton, QTreeWidget, QTreeWidgetItem, QVBoxLayout, QWidget
 
 if TYPE_CHECKING:
-    from ..views.code_view import CodeView
+    from angrmanagement.ui.views.code_view import CodeView
 
 
 class OptionType:
@@ -178,7 +177,6 @@ class QDecompilationOptions(QWidget):
         return STMT_OPTS + EXPR_OPTS
 
     def _init_widgets(self):
-
         # search box
         self._search_box = QLineEdit()
         self._search_box.textChanged.connect(self._on_search_box_text_changed)
