@@ -1,24 +1,20 @@
 from collections import defaultdict
-from typing import TYPE_CHECKING, List, Dict, Any
-import logging
+from typing import TYPE_CHECKING, Any, Dict, List
 
-from PySide6.QtCore import Qt, QPointF
+from PySide6.QtCore import QPointF, Qt
+
+from angrmanagement.utils.tree_graph_layouter import TreeGraphLayouter
 
-from ...utils.edge import Edge
-from ...utils.tree_graph_layouter import TreeGraphLayouter
 from .qgraph import QZoomableDraggableGraphicsView
 from .qgraph_arrow import QDepGraphArrow
 
 if TYPE_CHECKING:
-    from angrmanagement.ui.workspace import Workspace
     from angrmanagement.ui.views.dep_view import DependencyView
-
-
-_l = logging.getLogger(name=__name__)
+    from angrmanagement.ui.workspace import Workspace
+    from angrmanagement.utils.edge import Edge
 
 
 class QDependencyGraph(QZoomableDraggableGraphicsView):
-
     LEFT_PADDING = 2000
     TOP_PADDING = 2000
 
