@@ -1,26 +1,27 @@
-from typing import Optional, TYPE_CHECKING, Union
 import logging
-from sortedcontainers import SortedDict
-
-from PySide6.QtWidgets import QGraphicsScene, QAbstractSlider, QHBoxLayout, QAbstractScrollArea
-from PySide6.QtGui import QPainter
-from PySide6.QtCore import Qt, QRectF, QRect, QEvent
+from typing import TYPE_CHECKING, Optional, Union
 
+from angr.analyses.cfg.cfb import MemoryRegion, Unknown
 from angr.block import Block
 from angr.knowledge_plugins.cfg.memory_data import MemoryData
-from angr.knowledge_plugins import Function
-from angr.analyses.cfg.cfb import Unknown, MemoryRegion
-from angr.analyses.decompiler import Clinic
-from angr.analyses import Disassembly
+from PySide6.QtCore import QEvent, QRect, QRectF, Qt
+from PySide6.QtGui import QPainter
+from PySide6.QtWidgets import QAbstractScrollArea, QAbstractSlider, QGraphicsScene, QHBoxLayout
+from sortedcontainers import SortedDict
+
+from angrmanagement.config import Conf
 
-from ...config import Conf
 from .qblock import QLinearBlock
+from .qdisasm_base_control import DisassemblyLevel, QDisassemblyBaseControl
+from .qgraph import QSaveableGraphicsView
 from .qmemory_data_block import QMemoryDataBlock
 from .qunknown_block import QUnknownBlock
-from .qgraph import QSaveableGraphicsView
-from .qdisasm_base_control import QDisassemblyBaseControl, DisassemblyLevel
 
 if TYPE_CHECKING:
+    from angr.analyses import Disassembly
+    from angr.analyses.decompiler import Clinic
+    from angr.knowledge_plugins import Function
+
     from angrmanagement.logic.disassembly import InfoDock
 
 
@@ -176,7 +177,6 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
             self.reload()
 
     def _on_vertical_scroll_bar_triggered(self, action):
-
         action = QAbstractSlider.SliderAction(action)  # XXX: `action` is passed as an int
 
         if action == QAbstractSlider.SliderSingleStepAdd:
@@ -216,7 +216,6 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         self.redraw()
 
     def initialize(self):
-
         if self.cfb.am_none:
             return
 
@@ -297,7 +296,6 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
         self.setLayout(layout)
 
     def _update_size(self):
-
         # ask all objects to update their sizes
         for obj in self.objects:
             obj.clear_cache()
@@ -516,7 +514,7 @@ class QLinearDisassembly(QDisassemblyBaseControl, QAbstractScrollArea):
     def _addr_from_offset(self, mr, base_offset, offset):
         return mr.addr + (offset - base_offset)
 
-    def _get_disasm(self, func: Function) -> Optional[Union[Clinic, Disassembly]]:
+    def _get_disasm(self, func: "Function") -> Optional[Union["Clinic", "Disassembly"]]:
         """
         Get disassembly analysis object for a given function
         """
