@@ -1,14 +1,11 @@
-import logging
-
-from PySide6.QtWidgets import QFrame, QLabel, QVBoxLayout, QHBoxLayout, QScrollArea, QLineEdit, QWidget
+from PySide6.QtCore import QSize, Qt
 from PySide6.QtGui import QPainter, QPen
-from PySide6.QtCore import Qt, QSize
+from PySide6.QtWidgets import QFrame, QHBoxLayout, QLabel, QLineEdit, QScrollArea, QVBoxLayout, QWidget
+
+from angrmanagement.config import Conf
 
-from ...config import Conf
 from .qast_viewer import QASTViewer
 
-l = logging.getLogger("ui.widgets.qregister_viewer")
-
 
 class AddressPiece:
     __slots__ = ["address"]
@@ -46,7 +43,6 @@ class QMemoryView(QWidget):
             self._reload_objects()
 
     def paintEvent(self, event):
-
         if self.address is None:
             return
 
@@ -63,7 +59,6 @@ class QMemoryView(QWidget):
         y = MARGIN_TOP
 
         for obj in self._objects:
-
             obj_type = type(obj)
 
             if obj_type is NewLinePiece:
@@ -97,7 +92,6 @@ class QMemoryView(QWidget):
 
         addr_base = self.address
         for row in range(self.rows):
-
             addr = addr_base + row * self.cols
 
             # address
@@ -141,7 +135,6 @@ class QMemoryViewer(QFrame):
 
     @addr.setter
     def addr(self, v):
-
         if self._addr != v:
             self._addr = v
 
