@@ -1,27 +1,25 @@
 import logging
 from collections import defaultdict
 
-from ailment.statement import ConditionalJump, Jump
 from ailment.expression import Const
+from ailment.statement import ConditionalJump, Jump
 from angr.analyses.decompiler.clinic import Clinic
 
 from .edge import EdgeSort
 
-
-l = logging.getLogger("utils.cfg")
+log = logging.getLogger("utils.cfg")
 
 
 def _get_branch_instr(disassembly, node):
-
     if len(node.out_branches) > 1:
-        l.warning(
+        log.warning(
             "_get_branch_instr(): %s has more than one out_branches. Only the first one is considered for now. "
             "Report it to GitHub and it will be fixed.",
             node,
         )
     if not node.out_branches:
         # huh, why is it empty?
-        l.error("_get_branch_instr(): %s does not have any out branches. Please report to GitHub.", node)
+        log.error("_get_branch_instr(): %s does not have any out branches. Please report to GitHub.", node)
         return None
 
     # Get the instruction address that contains the jump
@@ -32,7 +30,7 @@ def _get_branch_instr(disassembly, node):
         instr = disassembly["instructions"][ins_addr]
     except KeyError:
         # the instruction is not found
-        l.error("_get_branch_instr(): Branch instruction %#x is not found in the Disassembly instance.", ins_addr)
+        log.error("_get_branch_instr(): Branch instruction %#x is not found in the Disassembly instance.", ins_addr)
         return None
 
     return instr
